****************************
The sherpa.sim.sample module
****************************

.. currentmodule:: sherpa.sim.sample

.. automodule:: sherpa.sim.sample

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      NormalParameterSampleFromScaleMatrix
      NormalParameterSampleFromScaleVector
      NormalSampleFromScaleMatrix
      NormalSampleFromScaleVector
      ParameterSampleFromScaleMatrix
      ParameterSampleFromScaleVector
      ParameterScale
      ParameterScaleMatrix
      ParameterScaleVector
      StudentTParameterSampleFromScaleMatrix
      StudentTSampleFromScaleMatrix
      UniformParameterSampleFromScaleVector
      UniformSampleFromScaleVector

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      multivariate_t
      multivariate_cauchy
      normal_sample
      uniform_sample
      t_sample

Class Inheritance Diagram
=========================

.. inheritance-diagram:: ParameterScale ParameterScaleVector ParameterScaleMatrix ParameterSampleFromScaleMatrix ParameterSampleFromScaleVector UniformParameterSampleFromScaleVector NormalParameterSampleFromScaleVector NormalParameterSampleFromScaleMatrix StudentTParameterSampleFromScaleMatrix NormalSampleFromScaleMatrix NormalSampleFromScaleVector UniformSampleFromScaleVector StudentTSampleFromScaleMatrix
   :parts: 1


